
class PinnacleError(Exception):
    pass


class ApiError(PinnacleError):
    def __init__(self, response):
        self.response = response
        self.status_code = response.status_code
        try:
            if type(self.response) == dict:
                self.message = self.response.get('message')
                self.details = self.response.get('code')
            else:
                self.message = self.response.json()['message']
                self.details = self.response.json()['code']
        except KeyError:
            self.message = 'UNKNOWN'
            self.details = None
        super(ApiError, self).__init__(self.message)


class PasswordError(PinnacleError):
    """Exception raised if password is not found"""

    def __init__(self):
        message = 'Password not found in environment variables, add or pass to APIClient'
        super(PasswordError, self).__init__(message)


class StatusCodeError(PinnacleError):
    """
    Exception raised if status code is incorrect.
    """

    def __init__(self, status_code):
        message = 'Status code error: %s' % status_code
        super(StatusCodeError, self).__init__(message)




import unittest
import unittest.mock as mock

from pinnacle.apiclient import APIClient
from pinnacle.endpoints.marketdata import MarketData


class MarketDataTest(unittest.TestCase):

    def setUp(self):
        client = APIClient('username', 'password')
        self.market_data = MarketData(client)

    @mock.patch('pinnacle.endpoints.marketdata.MarketData.process_response')
    @mock.patch('pinnacle.endpoints.marketdata.MarketData.request', return_value=mock.Mock())
    def test_get_sports(self, mock_request, mock_process_response):
        self.market_data.get_fixtures(sport_id=1, league_ids=[1, 2], since=10000)

        mock_request.assert_called_once_with(
            "GET", method='v1/fixtures', params={'sportId': 1, 'leagueIds': [1, 2], 'since': 10000}, session=None
        )
        assert mock_process_response.call_count == 1

    @mock.patch('pinnacle.endpoints.marketdata.MarketData.process_response')
    @mock.patch('pinnacle.endpoints.marketdata.MarketData.request', return_value=mock.Mock())
    def test_get_settled_fixtures(self, mock_request, mock_process_response):
        self.market_data.get_settled_fixtures(sport_id=1, league_ids=[1, 2], since=10000)

        mock_request.assert_called_once_with(
            "GET", method='v1/fixtures/settled', params={'sportId': 1, 'leagueIds': [1, 2], 'since': 10000}, session=None
        )
        assert mock_process_response.call_count == 1

    @mock.patch('pinnacle.endpoints.marketdata.MarketData.process_response')
    @mock.patch('pinnacle.endpoints.marketdata.MarketData.request', return_value=mock.Mock())
    def test_get_special_fixtures(self, mock_request, mock_process_response):
        self.market_data.get_special_fixtures(sport_id=1, league_ids=[1, 2], special_id=10, since=10000)

        mock_request.assert_called_once_with("GET", method='v1/fixtures/special',
                                             params={'sportId': 1, 'leagueIds': [1, 2], 'specialId': 10, 'since': 10000},
                                             session=None)
        assert mock_process_response.call_count == 1

    @mock.patch('pinnacle.endpoints.marketdata.MarketData.process_response')
    @mock.patch('pinnacle.endpoints.marketdata.MarketData.request', return_value=mock.Mock())
    def test_get_settled_special_fixtures(self, mock_request, mock_process_response):
        self.market_data.get_settled_special_fixtures(sport_id=1, league_ids=[1, 2], since=10000)

        mock_request.assert_called_once_with("GET", method='v1/fixtures/special/settled',
                                             params={'sportId': 1, 'leagueIds': [1, 2], 'since': 10000}, session=None)
        assert mock_process_response.call_count == 1

    @mock.patch('pinnacle.endpoints.marketdata.MarketData.process_response')
    @mock.patch('pinnacle.endpoints.marketdata.MarketData.request', return_value=mock.Mock())
    def test_get_inrunning(self, mock_request, mock_process_response):
        self.market_data.get_inrunning()

        mock_request.assert_called_once_with("GET", method='v1/inrunning', params={}, session=None)
        assert mock_process_response.call_count == 1

    @mock.patch('pinnacle.endpoints.marketdata.MarketData.process_response')
    @mock.patch('pinnacle.endpoints.marketdata.MarketData.request', return_value=mock.Mock())
    def test_get_odds(self, mock_request, mock_process_response):
        self.market_data.get_odds(sport_id=1, league_ids=[1, 2], since=10000)

        mock_request.assert_called_once_with(
            "GET", method='v1/odds',
            params={'sportId': 1, 'leagueIds': [1, 2], 'oddsFormat': 'DECIMAL', 'since': 10000}, session=None
        )
        assert mock_process_response.call_count == 1

    @mock.patch('pinnacle.endpoints.marketdata.MarketData.process_response')
    @mock.patch('pinnacle.endpoints.marketdata.MarketData.request', return_value=mock.Mock())
    def test_get_special_odds(self, mock_request, mock_process_response):
        self.market_data.get_special_odds(sport_id=1, league_ids=[1, 2], special_id=1000, since=10000)

        mock_request.assert_called_once_with(
            "GET", method='v1/odds/special',
            params={'sportId': 1, 'leagueIds': [1, 2], 'oddsFormat': 'DECIMAL', 'specialId': 1000, 'since': 10000},
            session=None
        )
        assert mock_process_response.call_count == 1

    @mock.patch('pinnacle.endpoints.marketdata.MarketData.process_response')
    @mock.patch('pinnacle.endpoints.marketdata.MarketData.request', return_value=mock.Mock())
    def test_get_line(self, mock_request, mock_process_response):
        self.market_data.get_line(sport_id=1, league_id=2, event_id=100, period_number=0, bet_type='MONEYLINE')

        mock_request.assert_called_once_with(
            "GET", method='v1/line',
            params={'sportId': 1, 'leagueId': 2, 'eventId': 100, 'periodNumber': 0,
                    'betType': 'MONEYLINE', 'oddsFormat': 'DECIMAL'},
            session=None
        )
        assert mock_process_response.call_count == 1

    @mock.patch('pinnacle.endpoints.marketdata.MarketData.process_response')
    @mock.patch('pinnacle.endpoints.marketdata.MarketData.request', return_value=mock.Mock())
    def test_get_special_lines(self, mock_request, mock_process_response):
        self.market_data.get_special_lines(special_id=102131, contestant_id=1000)

        mock_request.assert_called_once_with(
            "GET", method='v1/line/special',
            params={'specialId': 102131, 'contestantId': 1000, 'oddsFormat': 'DECIMAL'},
            session=None
        )
        assert mock_process_response.call_count == 1

    def test_get_teaser_groups(self):
        with self.assertRaises(NotImplementedError):
            self.market_data.get_teaser_groups()

    def test_get_teaser_odds(self):
        with self.assertRaises(NotImplementedError):
            self.market_data.get_teaser_odds()

    def test_get_teaser_lines(self):
        with self.assertRaises(NotImplementedError):
            self.market_data.get_teaser_lines()

    def test_get_parlay_lines(self):
        with self.assertRaises(NotImplementedError):
            self.market_data.get_parlay_lines()




import unittest
import unittest.mock as mock

from pinnacle.apiclient import APIClient
from pinnacle.endpoints.betting import Betting
from pinnacle.enums import WinRiskType, Boolean, OddsFormat


class BettingTest(unittest.TestCase):

    def setUp(self):
        client = APIClient('username', 'password')
        self.betting = Betting(client)

    @mock.patch('pinnacle.endpoints.betting.Betting.process_response')
    @mock.patch('pinnacle.endpoints.betting.Betting.request', return_value=mock.Mock())
    def test_get_bets(self, mock_request, mock_process_response):
        self.betting.get_bets(betids=[1, 2, 3, 4])

        mock_request.assert_called_once_with("GET", method='v1/bets', params={'betids': [1, 2, 3, 4]}, session=None)
        assert mock_process_response.call_count == 1

    @mock.patch('pinnacle.endpoints.betting.Betting.process_response')
    @mock.patch('pinnacle.endpoints.betting.Betting.request', return_value=mock.Mock())
    def test_place_bet(self, mock_request, mock_process_response):
        self.betting.place_bet(
            sport_id=1, event_id=2, line_id=10001, period_number=1, bet_type='MONEYLINE', stake=10.5, team=None,
            side=None, alt_line_id=None, win_risk_stake=WinRiskType.Risk.value, accept_better_line=Boolean.TRUE.value,
            odds_format=OddsFormat.Decimal.value, is_max_stake_bet=None, pitcher1_must_start=None,
            pitcher2_must_start=None, customer_reference=None, session=None
        )
        req_method, params = mock_request.call_args

        assert req_method[0] == "POST"
        assert params['method'] == 'v1/bets/place'
        assert params['data']['sportId'] == 1
        assert params['data']['eventId'] == 2
        assert params['data']['lineId'] == 10001
        assert params['data']['periodNumber'] == 1
        assert params['data']['betType'] == 'MONEYLINE'
        assert params['data']['stake'] == 10.5
        assert params['data']['winRiskStake'] == 'RISK'
        assert params['data']['acceptBetterLine'] == 1
        assert params['data']['oddsFormat'] == 'DECIMAL'

        assert mock_process_response.call_count == 1

    @mock.patch('pinnacle.endpoints.betting.Betting.process_response')
    @mock.patch('pinnacle.endpoints.betting.Betting.request', return_value=mock.Mock())
    def test_place_special_bet(self, mock_request, mock_process_response):
        self.betting.place_special_bet(
            line_id=10001, special_id=20002, contestant_id=1, stake=12, win_risk_stake=WinRiskType.Win.value,
            odds_format=OddsFormat.American.value, accept_better_line=Boolean.TRUE.value, session=None
        )
        req_method, params = mock_request.call_args

        assert req_method[0] == "POST"
        assert params['method'] == 'v1/bets/special'
        assert isinstance(params['data']['bets'], list)
        assert params['data']['bets'][0]['specialId'] == 20002
        assert params['data']['bets'][0]['lineId'] == 10001
        assert params['data']['bets'][0]['contestantId'] == 1
        assert params['data']['bets'][0]['stake'] == 12
        assert params['data']['bets'][0]['winRiskStake'] == 'WIN'
        assert params['data']['bets'][0]['acceptBetterLine'] == 1
        assert params['data']['bets'][0]['oddsFormat'] == 'AMERICAN'

        assert mock_process_response.call_count == 1

    def test_place_teaser_bet(self):
        with self.assertRaises(NotImplementedError):
            self.betting.place_teaser_bet()

    def test_place_parlay_bet(self):
        with self.assertRaises(NotImplementedError):
            self.betting.place_parlay_bet()



import datetime
import json

from ..compat import basestring, integer_types


class BaseResource(object):
    """
    Data structure based on a becket resource
        https://github.com/phalt/beckett
    """

    class Meta:
        identifier = 'id'  # The key with which you uniquely identify this resource.
        attributes = {'id': 'id'}  # Acceptable attributes that you want to display in this resource.
        sub_resources = {}  # sub resources are complex attributes within a resource
        datetime_attributes = ()  # Attributes to be converted to datetime

    def __init__(self, **kwargs):
        self._datetime_sent = kwargs.pop('date_time_sent', None)
        self.streaming_unique_id = kwargs.pop('streaming_unique_id', None)
        self.publish_time = kwargs.pop('publish_time', None)

        now = datetime.datetime.utcnow()
        self.datetime_created = now
        self._datetime_updated = now
        self._sub_resource_map = getattr(self.Meta, 'sub_resources', {})
        self._data = kwargs
        self.set_attributes(**kwargs)
        self._data['Latency'] = self.elapsed_time

    def set_sub_resources(self, **kwargs):
        """
        For each sub resource assigned to this resource, generate the
        sub resource instance and set it as an attribute on this instance.
        """
        for attribute_name, resource in self._sub_resource_map.items():
            sub_attr = kwargs.get(attribute_name)
            if sub_attr:
                if isinstance(sub_attr, list):
                    value = [resource(**x) for x in sub_attr]  # A list of sub resources is supported
                else:
                    value = resource(**sub_attr)  # So is a single resource
                setattr(self, resource.Meta.identifier, value)
            else:
                setattr(self, resource.Meta.identifier, [])  # [] = Empty resource

    def set_attributes(self, **kwargs):
        """
        Set the resource attributes from the kwargs.
        Only sets items in the `self.Meta.attributes` white list.
        Subclass this method to customise attributes.
        """
        if self._sub_resource_map:
            self.set_sub_resources(**kwargs)
            for key in self._sub_resource_map.keys():
                kwargs.pop(key, None)  # Don't let these attributes be overridden later
        for field, value in kwargs.items():
            if field in self.Meta.attributes:
                if field in self.Meta.datetime_attributes:
                    value = self.strip_datetime(value) or value
                setattr(self, self.Meta.attributes[field], value)

    def json(self):
        return self._data

    def message(self):
        return json.dumps(self._data)

    @staticmethod
    def strip_datetime(value):
        """
        Converts value to datetime if string or int.
        """
        if isinstance(value, basestring):
            try:
                return datetime.datetime.strptime(value, "%Y-%m-%dT%H:%M:%S.%fZ")
            except ValueError:
                return
        elif isinstance(value, integer_types):
            try:
                return datetime.datetime.utcfromtimestamp(value / 1e3)
            except (ValueError, OverflowError, OSError):
                return

    @property
    def elapsed_time(self):
        """
        Elapsed time between datetime sent and datetime created
        """
        if self._datetime_sent:
            return (self.datetime_created-self._datetime_sent).total_seconds()

    def __getattr__(self, item):
        """
        If item is an expected attribute in Meta
        return None, if not raise Attribute error.
        """
        if item in self.Meta.attributes.values():
            return
        else:
            return self.__getattribute__(item)

    def __repr__(self):
        return '<%s>' % self.__class__.__name__

    def __str__(self):
        return self.__class__.__name__



from pinnacle.baseclient import BaseClient
from pinnacle import endpoints


class APIClient(BaseClient):

    def __init__(self, username, password=None):
        super(APIClient, self).__init__(username, password)

        self.betting = endpoints.Betting(self)
        self.account = endpoints.Account(self)
        self.market_data = endpoints.MarketData(self)
        self.reference_data = endpoints.ReferenceData(self)

    def __repr__(self):
        return '<APIClient [%s]>' % self.username

    def __str__(self):
        return 'APIClient'



import os
import unittest
import requests
from requests.auth import HTTPBasicAuth

from pinnacle.baseclient import BaseClient
from pinnacle.exceptions import PasswordError

class BaseClientTest(unittest.TestCase):

    def test_baseclient_init(self):
        client = BaseClient(username='username', password='password')
        assert client.username == 'username'
        assert client.password == 'password'
        assert client.url == 'https://api.pinnaclesports.com/'
        assert isinstance(client.session, requests.Session)
        assert client.headers == {'Content-Type': 'application/json', 'Accept': 'application/json'}
        assert isinstance(client.auth, HTTPBasicAuth)

    def test_get_password(self):
        if 'PINNACLE_PW' in os.environ:
            client = BaseClient(username='username')
            assert client.password == os.environ['PINNACLE_PW']
        else:
            with self.assertRaises(PasswordError):
                BaseClient(username='username')




import unittest
import unittest.mock as mock

from pinnacle.apiclient import APIClient
from pinnacle.endpoints.account import Account


class AccountTest(unittest.TestCase):

    def setUp(self):
        client = APIClient('username', 'password')
        self.account = Account(client)

    @mock.patch('pinnacle.endpoints.account.Account.process_response')
    @mock.patch('pinnacle.endpoints.account.Account.request', return_value=mock.Mock())
    def test_get_account(self, mock_request, mock_process_response):
        self.account.get_account()

        mock_request.assert_called_once_with("GET", method='v1/client/balance', session=None)
        assert mock_process_response.call_count == 1




import os
import requests
from requests.auth import HTTPBasicAuth

from pinnacle.exceptions import PasswordError


class BaseClient(object):
    def __init__(self, username, password=None):
        """
        :param username: Pinnacle username.
        :param password: Password for supplied username, if None will look in for PINNACLE_PW in env variables.
        """
        self.username = username
        self.password = password
        self.url = 'https://api.pinnacle.com/'
        self.session = requests.Session()
        self.get_password()

    def get_password(self):
        """If password is not provided will look in environment
        variables for username+'password'
        """
        if self.password is None:
            if os.environ.get('PINNACLE_PW'):
                self.password = os.environ.get('PINNACLE_PW')
            else:
                raise PasswordError()

    @property
    def headers(self):
        """Set headers to be used in API requests."""
        return {
            'Content-Type': 'application/json',
            'Accept': 'application/json',
        }

    @property
    def auth(self):
        """Set auth param to be used in API requests."""
        return HTTPBasicAuth(username=self.username, password=self.password)



import json


class BaseEndpoint(object):

    def __init__(self, parent):
        """
        :param parent: API client.
        """
        self.client = parent

    def request(self, request_method, method, params={}, data={}, session=None):
        """
        :param request_method: type of request to be sent.
        :param method: Matchbook method to be used.
        :param params: Params to be used in request.
        :param data: data to be sent in request body.
        :param session: Requests session to be used, reduces latency.
        """
        session = session or self.client.session
        request_url = '%s%s' % (self.client.url, method)
        response = session.request(
            request_method, request_url, params=params, data=json.dumps(data),
            auth=self.client.auth, headers=self.client.headers,
        )
        return response

    @staticmethod
    def process_response(response_json, resource, date_time_sent, date_time_received=None):
        """
        :param response_json: Response in json format
        :param resource: Resource data structure
        :param date_time_sent: Date time sent
        :param date_time_received: Date time received response from request
        """
        if isinstance(response_json, list):
            return [
                resource(date_time_sent=date_time_sent, TIMESTAMP=date_time_received.strftime('%Y-%m-%d %H:%M:%S.%f'),
                         **x).json() for x in response_json]
        else:
            response_result = response_json.get('result', response_json)
            if isinstance(response_result, list):
                return [resource(date_time_sent=date_time_sent,
                                 TIMESTAMP=date_time_received.strftime('%Y-%m-%d %H:%M:%S.%f'),
                                 **x).json() for x in response_result]
            else:
                return resource(date_time_sent=date_time_sent,
                                TIMESTAMP=date_time_received.strftime('%Y-%m-%d %H:%M:%S.%f'),
                                **response_result).json()




from enum import Enum


class BetType(Enum):
    MoneyLine = 'MONEYLINE'
    TeamTotal = 'TEAM_TOTAL_POINTS'
    Spread = 'SPREAD'
    Total = 'TOTAL_POINTS'


class Boolean(Enum):
    TRUE = 1
    FALSE = 0


class Side(Enum):
    Over = 'OVER'
    Under = 'UNDER'


class TeamType(Enum):
    Team1 = 'Team1'
    Team2 = 'Team2'
    Draw = 'Draw'


class BetListType(Enum):
    Settled = 'SETTLED'
    Running = 'RUNNING'
    Cancelled = 'CANCELLED'


class EventStatus(Enum):
    Unavailable = 'H'
    LowerMax = 'I'
    Open = 'O'


class OddsFormat(Enum):
    Decimal = 'DECIMAL'
    American = 'AMERICAN'
    HongKong = 'HONGKONG'
    Indonesian = 'INDONESIAN'
    Malay = 'MALAY'


class WinRiskType(Enum):
    Win = 'WIN'
    Risk = 'RISK'


class FillType(Enum):
    Normal = 'Normal'
    FillAndKill = 'FILLANDKILL'
    FillMaxLimit = 'FILLMAXLIMIT'




# -*- coding: utf-8 -*-
import uuid
import datetime

from pinnacle import resources
from pinnacle.enums import OddsFormat, Boolean, WinRiskType, FillType
from pinnacle.endpoints.baseendpoint import BaseEndpoint
from pinnacle.utils import clean_locals


class Betting(BaseEndpoint):

    def get_bets(self, betids=None, betlist=None, unique_request_ids=None, from_date=None, to_date=None, session=None):
        """
        Get running bets or bets settled within the last 30 days.
        
        :param from_date: start date for bet query. Maximum 30 days between from_date and to_date. 
                          Required when betlist parameter is supplied.
        :param to_date: end date for bet query. to_date value is exclusive, meaning it cannot be equal to from_date.
                        Required when betlist parameter is supplied.
        :param betlist: type of bets to filter for, see pinnacle.enums.BetListType.
        :param betids: list of bet IDs, max 100, works for non settled bets and bets settled in the last 30 days.
        :param unique_request_ids: list of uniqueRequestIds to query bets placed within the last 30 mins and straight bets only. 
                                   If specified, is treated with highest priority, all other parameters are ignored. Maximum is 10 ids.
        :param session: requests session to be used.
        :returns: All bets fitting the filtered arguments supplied. 
        """
        from_date = from_date.strftime('%Y-%m-%d') if from_date is not None else from_date
        to_date = to_date.strftime('%Y-%m-%d') if to_date is not None else to_date
        params = clean_locals(locals())
        date_time_sent = datetime.datetime.utcnow()
        response = self.request("GET", method='v2/bets', params=params, session=session)
        return self.process_response(
            response.json(), resources.BetDetails, date_time_sent, datetime.datetime.utcnow()
        )

    def place_bet(self, sport_id, event_id, line_id, period_number, bet_type, stake, team=None, side=None,
                  alt_line_id=None, win_risk_stake=WinRiskType.Risk.value, accept_better_line=Boolean.TRUE.name,
                  odds_format=OddsFormat.Decimal.value, fill_type=FillType.Normal, pitcher1_must_start=None,
                  pitcher2_must_start=None, customer_reference=None, session=None):
        """
        Place bet in the system.
        
        :param sport_id: sport identification
        :param event_id: event identification
        :param line_id: Line identification
        :param period_number: This represents the period of the match. 
        :param bet_type: type of bet to be placed, see pinnacle.enums.BetType
        :param stake: Wagered amount in Clients currency
        :param team: Chosen team type. This is needed only for SPREAD, MONEYLINE and TEAM_TOTAL_POINTS bet types
        :param side: Chosen side. This is needed only for TOTAL_POINTS and TEAM_TOTAL_POINTS bet type
        :param alt_line_id: Alternate line identification
        :param win_risk_stake: Whether the stake amount is risk or win amount
        :param accept_better_line: Whether or not to accept a bet when there is a line change in favor of the client.
        :param odds_format: Bet is processed with this odds format.
        :param fill_type: FillAndKill, if stake > maxbet will fill max bet. FillMaxLimit, ignore stake and stake to max bet.
        :param pitcher1_must_start: Baseball only. Refers to the pitcher for TEAM_TYPE. Team1. 
                                    Only for MONEYLINE bet type, for all other bet types this has to be TRUE.
        :param pitcher2_must_start: Baseball only. Refers to the pitcher for TEAM_TYPE. Team2. 
                                    Only for MONEYLINE bet type, for all other bet types this has to be TRUE.
        :param customer_reference: Reference for customer to use.
        :param session: requests session to be used.
        :return: bet success/failure.
        """
        unique_request_id = str(uuid.uuid4())
        params = clean_locals(locals())
        date_time_sent = datetime.datetime.utcnow()
        response = self.request("POST", method='/v2/bets/straight', data=params, session=session)
        return self.process_response(
            response.json(), resources.PlaceBetDetails, date_time_sent, datetime.datetime.utcnow()
        )

    def place_special_bet(self, line_id, special_id, contestant_id, stake, win_risk_stake=WinRiskType.Risk.value,
                          odds_format=OddsFormat.Decimal.value, accept_better_line=Boolean.TRUE.name, session=None):
        """
        Place special bet in the system.
        
        :param line_id: Line identification
        :param special_id: Special identification.
        :param contestant_id: Contestant identification.
        :param stake: Wagered amount in Clients currency.
        :param win_risk_stake: Whether the stake amount is risk or win amount
        :param odds_format: Bet is processed with this odds format.
        :param accept_better_line: Whether or not to accept a bet when there is a line change in favor of the client.
        :param session: requests session to be used.
        :return: bet success/failure.
        """
        unique_request_id = str(uuid.uuid4())
        params = {'bets': [clean_locals(locals())]}
        date_time_sent = datetime.datetime.utcnow()
        response = self.request("POST", method='v1/bets/special', data=params, session=session)
        return self.process_response(
            response.json().get('bets', []), resources.PlaceSpecialBetDetails, date_time_sent, datetime.datetime.utcnow()
        )

    def place_teaser_bet(self):
        raise NotImplementedError

    def place_parlay_bet(self):
        raise NotImplementedError




import unittest
import unittest.mock as mock

from pinnacle.utils import check_status_code, clean_locals, to_camel_case
from pinnacle.exceptions import StatusCodeError


class UtilsTest(unittest.TestCase):

    def test_check_status_code_ok(self):
        resp = mock.Mock()
        resp.status_code = 200

        assert check_status_code(resp) is None

    def test_check_status_code_fail(self):
        resp = mock.Mock()
        resp.status_code = 400

        with self.assertRaises(StatusCodeError):
            check_status_code(resp)

    def test_convert_to_camel_case(self):
        assert to_camel_case('hello_world') == 'helloWorld'

    def test_clean_locals(self, test_val=None, filter=123):
        params = clean_locals(locals())
        assert params == {'filter': 123}



import datetime

from pinnacle import resources
from pinnacle.endpoints.baseendpoint import BaseEndpoint


class Account(BaseEndpoint):

    def get_account(self, session=None):
        """
        Get account info.
        
        :return: account info
        """
        date_time_sent = datetime.datetime.utcnow()
        response = self.request("GET", method='v1/client/balance', session=session)
        return self.process_response(
            response.json(), resources.AccountDetails, date_time_sent, datetime.datetime.utcnow()
        )




from setuptools import setup, find_packages
from pinnacle import __version__

setup(
    name="daydreamer",
    version=__version__,
    author="Nick Georgiadis",
    author_email="nickgeo_@hotmail.com",
    description="Daydreamer Nick API Python wrapper",
    url="https://github.com/rozzac90/pinnacle",
    packages=find_packages(),
    install_requires=[line.strip() for line in open("requirements.txt")],
    long_description=open('README.md').read(),
    tests_require=['pytest'],
)




from pinnacle.endpoints.account import Account
from pinnacle.endpoints.betting import Betting
from pinnacle.endpoints.marketdata import MarketData
from pinnacle.endpoints.referencedata import ReferenceData
